@@ -60,6 +60,9 @@ class Settings(QtWidgets.QDialog):
             self.usepywinkeyer_radioButton.setChecked(
                 bool(self.preference.get("cwtype") == 2)
             )
+            self.usecat4cw_radioButton.setChecked(
+                bool(self.preference.get("cwtype") == 3)
+            )
             self.connect_to_server.setChecked(bool(self.preference.get("useserver")))
             self.multicast_group.setText(
                 str(self.preference.get("multicast_group", ""))
@@ -110,6 +113,8 @@ class Settings(QtWidgets.QDialog):
             self.preference["cwtype"] = 1
         if self.usepywinkeyer_radioButton.isChecked():
             self.preference["cwtype"] = 2
+        if self.usecat4cw_radioButton.isChecked():
+            self.preference["cwtype"] = 3
         self.preference["useserver"] = self.connect_to_server.isChecked()
         self.preference["multicast_group"] = self.multicast_group.text()
         self.preference["multicast_port"] = self.multicast_port.text()
